@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.8.1"
+    version = "1.8.2"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -113,12 +113,12 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         project = activity.project
         group = activity.group
 
-        self._post(group, project)
+        self._post(group, project, activity)
 
     def _post(self, group, project, event=''):
         custom_keyword = self.get_option("custom_keyword", project)
         # # 告警次数阀值
-        number_alarm = self.get_option("number_alarm", project) if self.get_option("number_alarm", project) else 10
+        # number_alarm = self.get_option("number_alarm", project) if self.get_option("number_alarm", project) else 10
         phones = self.get_option("phones", project)
         #
         issue_link = group.get_absolute_url(params={"referrer": "dingtalknotify"})
@@ -128,8 +128,8 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
         payload = f"{payload} > 项目名称: {project.name} \n\n"
         payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
-        # payload = f"{payload} > 查看详情: <font color=blue>[{group.title if 'unknown' not in group.title else 'unknown'}]({issue_link})</font> \n\n"
-        # payload = f"{payload} > 具体报错: {group.message} \n\n"
+        payload = f"{payload} > 查看详情: <font color=blue>[{group.title if 'unknown' not in group.title else 'unknown'}]({issue_link})</font> \n\n"
+        payload = f"{payload} > 具体报错: {group.message} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
         payload = f"{payload} > Hi: {event.__dict__} \n\n"
         payload = f"{payload} > Group: {group.__dict__} \n\n"
